SystemOrganization addCategory: #'Orion-Core'!
SystemOrganization addCategory: #'Orion-File'!
SystemOrganization addCategory: #'Orion-Workspace'!
SystemOrganization addCategory: #'Orion-Handlers'!
SystemOrganization addCategory: #'Orion-Implementation'!
SystemOrganization addCategory: #'Orion-Test'!

TestCase subclass: #ORObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Test'!

ORObjectTest subclass: #ORExceptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Test'!

!ORExceptionTest methodsFor: 'private' stamp: 'pmm 3/23/2011 10:17'!
createFromMessageNotUnderstood
	[ self raiseFromMessageNotUnderstood ]
		on: MessageNotUnderstood
		do: [ :error | ^ ORException fromError: error ]! !

!ORExceptionTest methodsFor: 'private' stamp: 'pmm 3/23/2011 11:12'!
createFromWarning
	[ self raiseWarning ]
		on: Warning
		do: [ :error | ^ ORException fromError: error ]! !

!ORExceptionTest methodsFor: 'private' stamp: 'pmm 3/23/2011 10:14'!
raiseFromMessageNotUnderstood
	nil requestContext! !

!ORExceptionTest methodsFor: 'private' stamp: 'pmm 3/23/2011 11:12'!
raiseWarning
	Warning signal: 'it''s getting a bit cold'! !

!ORExceptionTest methodsFor: 'testing' stamp: 'pmm 3/23/2011 11:01'!
testFromMessageNotUnderstood
	self
		assert: (self createFromMessageNotUnderstood )
		serializesTo:
			'{',
   				'"httpCode":500,',
				'"severity":"error",',
   				'"message":"MessageNotUnderstood: receiver of \"requestContext\" is nil",', 
				'"detailedMessage":"receiver of \"requestContext\" is nil"', 
			'}'! !

!ORExceptionTest methodsFor: 'testing' stamp: 'pmm 3/23/2011 11:16'!
testFromWarning
	self
		assert: (self createFromWarning)
		serializesTo:
			'{',
   				'"httpCode":500,',
				'"severity":"warning",',
   				'"message":"Warning: it''s getting a bit cold",', 
				'"detailedMessage":"it''s getting a bit cold"', 
			'}'! !

ORObjectTest subclass: #ORFileAttributesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Test'!

ORObjectTest subclass: #ORFileTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Test'!

!ORFileTest methodsFor: 'testing' stamp: 'NickAger 8/10/2011 07:05'!
testFromString
	| json file |
	json := '{
		"Name" : "myfolder",
		"Directory" : "true"
	}'.
	file := ORFile fromJson: json.
	self assert: file name = 'myfolder'.
	self assert: file directory! !

!ORFileTest methodsFor: 'testing' stamp: 'pmm 3/28/2011 04:25'!
testSerializeWithAttributes
	| file |
	file := ORFile new
		name: 'myfile.txt';
		location: 'http://example.com/file/MyProj/myfile.txt';
		eTag: '35fd43td3';
		directory: false;
		localTimeStamp: 1234345009837;
		charset: 'UTF-8';
		contentType: 'text/plain';
		attributes: (ORFileAttributes new
			readOnly: false;
			executable: true;
			yourself).
	self
		assert: file
		serializesTo:
			'{',
				'"Name":"myfile.txt",',
				'"Location":"http://example.com/file/MyProj/myfile.txt",',
				'"Directory":false,',
				'"ETag":"35fd43td3",',
				'"LocalTimeStamp":1234345009837,',
				'"Charset":"UTF-8",',
				'"ContentType":"text/plain",',
				'"Attributes":{',
					'"ReadOnly":false,',
					'"Executable":true',
				'}',
			'}'! !

!ORObjectTest class methodsFor: 'testing' stamp: 'pmm 3/23/2011 10:05'!
isAbstract
	^ self name = #ORObjectTest! !

!ORObjectTest methodsFor: 'private' stamp: 'NickAger 8/10/2011 07:03'!
assert: anObject serializesTo: aString
	| json |
	json := String streamContents: [ :stream |
		anObject jsonOn: stream ].
	self
		assert: json = aString
		description:	'Expected: ' , aString printString , ', Actual: ' , json printString
		resumable: true! !

ORObjectTest subclass: #ORProjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Test'!

!ORProjectTest methodsFor: 'testing' stamp: 'pmm 3/23/2011 11:34'!
testSerialization
	| workspace |
	workspace := ORProject new
		id: 'A7';
		location: 'http://localhost:8080/workspace/E9/A7';
		contentLocation: 'http://localhost:8080/file/A7';
		name: 'My Project'.
	self
		assert: workspace
		serializesTo:
			'{',	
				'"Id":"A7",',
				'"Name":"My Project",',
				'"Location":"http://localhost:8080/workspace/E9/A7",',
				'"ContentLocation":"http://localhost:8080/file/A7"',
			'}'! !

ORObjectTest subclass: #ORWorkspaceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Test'!

!ORWorkspaceTest methodsFor: 'testing' stamp: 'NickAger 8/9/2011 18:58'!
testProjectsAndChilderen
	| workspace |
	workspace := ORWorkspace new
			id: 'E9';
			name: 'My Dev Workspace';
			projects: (Array with: (
				ORProject  new
					id: 'h8';
					location: 'http://example.com/workspaces/projects/h8';
					yourself));
			children: (Array with: (
				ORFile new
					name: 'My Project';
					location: 'http://example.com/file/h8';
					directory: true;
					yourself));
			yourself.
	self
		assert: workspace
		serializesTo:
			'{',
				'"Id":"E9",',
				'"Name":"My Dev Workspace",',
				'"Projects":[',
					'{',
						'"Id":"h8",',
						'"Location":"http://example.com/workspaces/projects/h8"',
					'}',
				'],',
				'"Children":[',
					'{',
						'"Name":"My Project",',
						'"Location":"http://example.com/file/h8",',
						'"Directory":true',
					'}',
				']',
			'}'! !

!ORWorkspaceTest methodsFor: 'testing' stamp: 'pmm 3/28/2011 04:57'!
testUserWithWorkspaces
	| user |
	user := ORWorkspaceUser new
		id: '987fd076g5sd6';
		userName: 'Sam';
		workspaces: (Array with: (ORWorkspace new
			id: 'E9';
			location: 'http://example.com/workspace/E9';
			lastModified: 1291907325193;
			name: 'My Dev Workspace';
			yourself)).
	self
		assert: user
		serializesTo:
			'{',
				'"Id":"987fd076g5sd6",',
				'"UserName":"Sam",',
				'"Workspaces":[',
					'{',
						'"Id":"E9",',
						'"Name":"My Dev Workspace",',
						'"Location":"http://example.com/workspace/E9",',
						'"LastModified":1291907325193',
					'}',
			']}'! !

WARestfulHandler subclass: #ORHandler
	instanceVariableNames: 'implementation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Handlers'!

ORHandler subclass: #ORFileHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Handlers'!

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
createFile: path
	<put>
	<path: '/*path*'>
	self notYetImplemented! !

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
createFileFromJson: path
	<put>
	<consumes: 'application/json'>
	<path: '/*path*'>
	self notYetImplemented! !

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
getDirectoryContents: path depth: depth
	<get>
	<path: '/*path*?depth={depth}'>
	self notYetImplemented! !

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
getFile: path
	<get>
	<path: '/*path*'>
	self notYetImplemented! !

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
getFile: path parts: parts
	<get>
	<path: '/*path*?parts={parts}'>
	self notYetImplemented! !

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
updateFileContents: path
	<put>
	<path: '/*path*'>
	self notYetImplemented! !

!ORFileHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
updateFileContents: path parts: parts
	<put>
	<path: '/*path*?parts={parts}'>
	self notYetImplemented! !

!ORHandler methodsFor: 'convenience' stamp: 'pmm 3/23/2011 07:50'!
answerJson: aBlock
	self answerJson: aBlock ifSuccessful: WAResponse statusOk! !

!ORHandler methodsFor: 'convenience' stamp: 'NickAger 8/10/2011 07:07'!
answerJson: aBlock ifSuccessful: anInteger
	self requestContext respond: [ :response |
		| result |
		result := aBlock
			on: Error
			do: [ :error | ORException fromError: error ].
		response status: (response isError
			ifTrue: [ result httpCode ]
			ifFalse: [ anInteger ]).
		result jsonOn: response stream ]! !

!ORHandler methodsFor: 'convenience' stamp: 'pmm 3/20/2011 00:22'!
createOptions
	^ self requestContext request headerAt: 'x-create-options' ifAbsent: [ nil ]! !

!ORHandler methodsFor: 'convenience' stamp: 'pmm 3/23/2011 07:30'!
fileImplementation
	^ implementation fileImplementation! !

!ORHandler methodsFor: 'convenience' stamp: 'pmm 3/20/2011 00:21'!
slug
	^ self requestContext request headerAt: 'slug' ifAbsent: [ nil ]! !

!ORHandler methodsFor: 'convenience' stamp: 'pmm 3/23/2011 07:30'!
workspaceImplementation
	^ implementation workspaceImplementation! !

ORHandler subclass: #ORWorkspaceHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Handlers'!

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
addNewProjectToWorkspace: workspaceId
	<post>
	<path: '/{workspaceId}'>
	self notYetImplemented! !

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
createNewWorkspace
	<post>
	<path: '/'>
	self answerJson: [ self workspaceImplementation createNewWorkspace: self slug ] ifSuccessful: WAResponse statusCreated! !

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
deleteWorkspace: workspaceId
	<delete>
	<path: '/{workspaceId}'>
	self notYetImplemented! !

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
getAllAvailableWorkspaces
	<get>
	<path: '/'>
	self notYetImplemented! !

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
getWorkspaceMetadata: workspaceId
	<get>
	<path: '/{workspaceId}'>
	self notYetImplemented! !

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
removeProject: projectId fromWorkspace: workspaceId
	<delete>
	<path: '/{workspaceId}/{projectId}'>
	self notYetImplemented! !

!ORWorkspaceHandler methodsFor: 'api' stamp: 'lr 7/26/2011 14:54'!
updateWorkspaceMetadata: workspaceId
	<put>
	<path: '/{workspaceId}'>
	self notYetImplemented! !

WAErrorHandler subclass: #ORErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Handlers'!

!ORErrorHandler methodsFor: 'actions' stamp: 'NickAger 8/10/2011 07:07'!
handleDefault: anError
	self requestContext respond: [ :response |
		| exception |
		exception := ORException fromError: anError.
		exception jsonOn: response stream ]! !

MJObject subclass: #ORObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Core'!

!ORObject commentStamp: 'pmm 3/19/2011 23:28' prior: 0!
I am the abstract base class for all Orion response objects. I provide JSON serialization.!

ORObject subclass: #ORException
	instanceVariableNames: 'httpCode code severity message detailedMessage cause seeAlso'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Core'!

!ORException commentStamp: 'pmm 3/23/2011 07:41' prior: 0!
ORException has not been documented yet. The class comment should describe the purpose of the class, its collaborations and its variables.

Instance Variables:
	httpCode			<Integer>
	code				<Integer>
	severity			<String>
	message			<String>
	detailedMessage	<String>
	cause				<ORException>
	seeAlso			<WAUrl>
				
httpCode
	- Integer HTTP response code
	
code
	- Application specific integer response code

severity
	- One of "error", "warning", "info", "cancel", or "ok"
	
message
	- high level error message
	
detailedMessage
	- Detailed error message
	
cause
	- JSON object representation of another status that is the cause of this status (used for exception chaining)
	
seeAlso
	- URL of a page for more information on how to resolve the error 	No
!

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:52'!
descriptionCause
	^ MAToOneRelationDescription new
		selectorAccessor: #cause;
		jsonName: 'cause';
		priority: 600;
		yourself! !

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:45'!
descriptionCode
	^ MANumberDescription new
		selectorAccessor: #code;
		jsonName: 'code';
		priority: 400;
		yourself! !

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:51'!
descriptionDetailedMessage
	^ MANumberDescription new
		selectorAccessor: #detailedMessage;
		jsonName: 'detailedMessage';
		priority: 500;
		yourself! !

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:34'!
descriptionHttpCode
	^ MANumberDescription new
		selectorAccessor: #httpCode;
		jsonName: 'httpCode';
		priority: 100;
		beRequired;
		yourself! !

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:34'!
descriptionMessage
	^ MAStringDescription new
		selectorAccessor: #message;
		jsonName: 'message';
		priority: 300;
		beRequired;
		yourself! !

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:53'!
descriptionSeeAlso
	^ MAStringDescription new
		selectorAccessor: #seeAlso;
		jsonName: 'seeAlso';
		priority: 700;
		yourself! !

!ORException class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 10:49'!
descriptionSeverity
	^ MASingleOptionDescription new
		options: self severities;
		selectorAccessor: #severity;
		jsonName: 'severity';
		priority: 200;
		beRequired;
		yourself! !

!ORException class methodsFor: 'instance creation' stamp: 'pmm 3/23/2011 09:42'!
fromError: anError
	| exception messageText |
	exception := self
		httpCode: WAResponse statusInternalServerError
		severity: (self severityFor: anError)
		message: anError description.
	messageText := anError messageText.
	messageText isEmptyOrNil ifFalse: [
		exception detailedMessage: messageText ].
	^ exception! !

!ORException class methodsFor: 'instance creation' stamp: 'pmm 3/23/2011 10:18'!
httpCode: aCodeInteger severity: aSeverityString message: aMessageString
	^ self basicNew
		initializeWithHttpCode: aCodeInteger
		severity: aSeverityString
		message: aMessageString! !

!ORException class methodsFor: 'accessing-severity' stamp: 'pmm 3/23/2011 10:48'!
severities
	^ Array
		with: self severityError
		with: self severityWarning
		with: self severityInfo
		with: self severityCancel
		with: self severityOk! !

!ORException class methodsFor: 'accessing-severity' stamp: 'pmm 3/23/2011 09:35'!
severityCancel
	^ 'cancel'! !

!ORException class methodsFor: 'accessing-severity' stamp: 'pmm 3/23/2011 09:34'!
severityError
	^ 'error'! !

!ORException class methodsFor: 'private' stamp: 'pmm 3/23/2011 09:37'!
severityFor: anError
	^ (anError isKindOf: Warning)
		ifTrue: [ self severityWarning ]
		ifFalse: [ self severityError ]! !

!ORException class methodsFor: 'accessing-severity' stamp: 'pmm 3/23/2011 09:35'!
severityInfo
	^ 'info'! !

!ORException class methodsFor: 'accessing-severity' stamp: 'pmm 3/23/2011 09:35'!
severityOk
	^ 'ok'! !

!ORException class methodsFor: 'accessing-severity' stamp: 'pmm 3/23/2011 09:34'!
severityWarning
	^ 'warning'! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:46'!
cause
	^ cause! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:46'!
cause: anORException
	cause := anORException
! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
code
	^ code! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
code: anInteger
	code := anInteger
! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
detailedMessage
	^ detailedMessage! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
detailedMessage: aString
	detailedMessage := aString
! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
httpCode
	^ httpCode! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
httpCode: anInteger
	httpCode := anInteger
! !

!ORException methodsFor: 'initialize-release' stamp: 'pmm 3/23/2011 09:30'!
initializeWithHttpCode: aCodeInteger severity: aSeverityString message: aMessageString
	self initialize.
	httpCode := aCodeInteger.
	severity := aSeverityString.
	message := aMessageString! !

!ORException methodsFor: 'testing' stamp: 'pmm 3/23/2011 07:43'!
isError
	^ true! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
message
	^ message! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
message: aString
	message := aString
! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
seeAlso
	^ seeAlso! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
seeAlso: aWAUrl
	seeAlso := aWAUrl! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
severity
	^ severity! !

!ORException methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:48'!
severity: aString
	severity := aString
! !

ORObject subclass: #ORFile
	instanceVariableNames: 'name directory location eTag localTimeStamp attributes children parents charset contentType contentLength'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-File'!

!ORFile commentStamp: 'pmm 3/19/2011 23:51' prior: 0!
I represent a file.

Instance Variables:
	name				<String>
	directory			<Boolean>
	eTag				<String>
	localTimeStamp	<Integer>
	attributes			<ORFileAttributes>
	children			<SequenceableCollection>
	parents 			<SequenceableCollection>
	charset				<String>
	contentType		<String>
	contentLength		<Integer>
		
name
	- String file name

directory
	- "true" for a directory and "false" for a file

eTag
	- Opaque token representing a unique state of this file or directory

localTimeStamp
	- last modified time in milliseconds since January 1, 1970
	
attributes
	- The file's permission attributes
	
children
	- The children of a directory. JSON representations of files (directories) may include a Children attribute. The value
of this attribute is an array of file objects, one for each child of the directory. Those
children may in turn include Children attributes for listing their own children. In this
way, a JSON file representation may represent an entire file system sub-tree.

	
parents
	- The parents of a file or directory. JSON representations of files may include a Parents attribute. The value of this
attribute is an array of file objects, one for each parent. The array is ordered so that
the first element is the immediate parent, the second entry is the grandparent, etc.
Note that it is not possible in all cases to accurately represent the parents of a file.
For example the target of a symbolic link may be seen to have multiple direct parents.
The purpose of the Parents attribute is to allow for logical navigation (such as a ".."
link to a file's parent), rather than providing a canonical physical description of the file
hierarchy. For example, deleting the parent of a file is not guaranteed to delete the
file, due to the possibility of other parents of that file continuing to exist.

charset
	- file character set (method used to convert the file bytes into characters)

contentType
	- MIME content type

contentLength
	- The length of the file in bytes


!

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:39'!
descriptionAttributes
	^ MAToOneRelationDescription new
		selectorAccessor: #attributes;
		priority: 900;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:40'!
descriptionCharset
	^ MAStringDescription new
		selectorAccessor: #charset;
		priority: 600;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:39'!
descriptionChildren
	^ MAToManyRelationDescription new
		selectorAccessor: #children;
		priority: 1000;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:40'!
descriptionContentLength
	^ MANumberDescription new
		selectorAccessor: #contentLength;
		priority: 800;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:40'!
descriptionContentType
	^ MAStringDescription new
		selectorAccessor: #contentType;
		priority: 700;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:33'!
descriptionDirectory
	^ MABooleanDescription new
		selectorAccessor: #directory;
		priority: 300;
		beRequired;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:33'!
descriptionETag
	^ MAStringDescription new
		selectorAccessor: #eTag;
		priority: 400;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/26/2011 22:59'!
descriptionLocalTimeStamp
	^ MANumberDescription new
		selectorAccessor: #localTimeStamp;
		priority: 500;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:33'!
descriptionLocation
	^ MAStringDescription new
		selectorAccessor: #location;
		priority: 200;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 09:25'!
descriptionName
	^ MAStringDescription new
		selectorAccessor: #name;
		priority: 100;
		beRequired;
		yourself! !

!ORFile class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 17:39'!
descriptionParents
	^ MAToManyRelationDescription new
		selectorAccessor: #parents;
		priority: 1100;
		yourself! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
attributes
	^ attributes! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
attributes: anORFileAttributes
	attributes := anORFileAttributes
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
charset
	^ charset! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
charset: aString
	charset := aString
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
children
	^ children! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
children: anObject
	children := anObject! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
contentLength
	^ contentLength! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
contentLength: anInteger
	contentLength := anInteger
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
contentType
	^ contentType
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
contentType: aString
	contentType := aString
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
directory
	^ directory! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
directory: aBoolean
	directory := aBoolean
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
eTag
	^ eTag! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
eTag: aBoolean
	eTag := aBoolean
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
localTimeStamp
	^ localTimeStamp! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
localTimeStamp: anInteger
	localTimeStamp := anInteger
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 17:32'!
location
	^ location! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 17:32'!
location: aString
	location := aString
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
name
	^ name
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
name: aString
	name := aString
! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
parents
	^ parents! !

!ORFile methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:28'!
parents: aCollectionOfORFile
	parents := aCollectionOfORFile
! !

ORObject subclass: #ORFileAttributes
	instanceVariableNames: 'readOnly executable hidden archive symbolicLink'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-File'!

!ORFileAttributes commentStamp: 'pmm 3/19/2011 23:20' prior: 0!
I represent a files permission attributes.

Instance Variables:
	readOnly		<Boolean>
	executable		<Boolean>
	hidden			<Boolean>
	archive			<Boolean>
	symbolicLink	<Boolean>
		
readOnly
	- Whether the file is modifiable.
	
executable
	- Whether the file is executable 

hidden
	- Whether the file is hidden 

archive
	- Whether the file has the archive bit set 

symbolicLink
	- Whether the file is a symbolic link
!

!ORFileAttributes class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 09:44'!
descriptionArchive
	^ MABooleanDescription new
		selectorAccessor: #archive;
		priority: 400;
		yourself! !

!ORFileAttributes class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 09:43'!
descriptionExecutable
	^ MABooleanDescription new
		selectorAccessor: #executable;
		priority: 200;
		yourself! !

!ORFileAttributes class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 09:43'!
descriptionHidden
	^ MABooleanDescription new
		selectorAccessor: #hidden;
		priority: 300;
		yourself! !

!ORFileAttributes class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 09:43'!
descriptionReadOnly
	^ MABooleanDescription new
		selectorAccessor: #readOnly;
		priority: 100;
		yourself! !

!ORFileAttributes class methodsFor: 'accessing-description' stamp: 'pmm 3/24/2011 09:44'!
descriptionSymbolicLink
	^ MABooleanDescription new
		selectorAccessor: #symbolicLink;
		priority: 500;
		yourself! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
archive
	^ archive! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
archive: aBoolean
	archive := aBoolean
! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
executable
	^ executable! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
executable: aBoolean
	executable := aBoolean
! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
hidden
	^ hidden! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
hidden: aBoolean
	hidden := aBoolean
! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
readOnly
	^ readOnly! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
readOnly: aBoolean
	readOnly := aBoolean
! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
symbolicLink
	^ symbolicLink! !

!ORFileAttributes methodsFor: 'accessing' stamp: 'pmm 3/24/2011 09:42'!
symbolicLink: aBoolean
	symbolicLink := aBoolean
! !

!ORObject methodsFor: 'testing' stamp: 'pmm 3/23/2011 07:43'!
isError
	^ false! !

ORObject subclass: #ORProject
	instanceVariableNames: 'id location contentLocation name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Workspace'!

!ORProject class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 11:35'!
descriptionContentLocation
	^ MAStringDescription new
		selectorAccessor: #contentLocation;
		priority: 400;
		yourself! !

!ORProject class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 11:35'!
descriptionId
	^ MAStringDescription new
		selectorAccessor: #id;
		priority: 100;
		beRequired;
		yourself! !

!ORProject class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 11:35'!
descriptionLocation
	^ MAStringDescription new
		selectorAccessor: #location;
		priority: 300;
		yourself! !

!ORProject class methodsFor: 'accessing-description' stamp: 'pmm 3/23/2011 11:35'!
descriptionName
	^ MAStringDescription new
		selectorAccessor: #name;
		priority: 200;
		yourself! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
contentLocation
	^ contentLocation! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
contentLocation: aString
	contentLocation := aString
! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
id
	^ id! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
id: aString
	id := aString
! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
location
	^ location! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
location: aString
	location := aString
! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
name
	^ name
! !

!ORProject methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:26'!
name: aString
	name := aString
! !

ORObject subclass: #ORWorkspace
	instanceVariableNames: 'id name location lastModified projects children'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Workspace'!

!ORWorkspace class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:42'!
descriptionChildren
	^ MAToManyRelationDescription new
		selectorAccessor: #children;
		priority: 600;
		yourself! !

!ORWorkspace class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:39'!
descriptionId
	^ MAStringDescription new
		selectorAccessor: #id;
		priority: 100;
		beRequired;
		yourself! !

!ORWorkspace class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:40'!
descriptionLastModified
	^ MAStringDescription new
		selectorAccessor: #lastModified;
		priority: 400;
		yourself! !

!ORWorkspace class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:40'!
descriptionLocation
	^ MAStringDescription new
		selectorAccessor: #location;
		priority: 300;
		yourself! !

!ORWorkspace class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:39'!
descriptionName
	^ MAStringDescription new
		selectorAccessor: #name;
		priority: 200;
		yourself! !

!ORWorkspace class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:42'!
descriptionProjects
	^ MAToManyRelationDescription new
		selectorAccessor: #projects;
		priority: 500;
		yourself! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
children
	^ children! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
children: aCollection
	children := aCollection
! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
id
	^ id! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
id: aString
	id := aString
! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:43'!
lastModified
	^ lastModified! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:43'!
lastModified: anInteger
	lastModified := anInteger
! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
location
	^ location! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
location: aString
	location := aString
! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
name
	^ name
! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
name: aString
	name := aString
! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
projects
	^ projects! !

!ORWorkspace methodsFor: 'accessing' stamp: 'pmm 3/23/2011 11:24'!
projects: aCollectionOfProjects
	projects := aCollectionOfProjects
! !

ORObject subclass: #ORWorkspaceUser
	instanceVariableNames: 'userName id workspaces'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Workspace'!

!ORWorkspaceUser class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:34'!
descriptionId
	^ MAStringDescription new
		selectorAccessor: #id;
		priority: 100;
		yourself! !

!ORWorkspaceUser class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:34'!
descriptionUserName
	^ MAStringDescription new
		selectorAccessor: #userName;
		priority: 200;
		yourself! !

!ORWorkspaceUser class methodsFor: 'accessing-description' stamp: 'pmm 3/28/2011 04:35'!
descriptionWorkspaces
	^ MAToManyRelationDescription new
		selectorAccessor: #workspaces;
		priority: 300;
		yourself! !

!ORWorkspaceUser methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:33'!
id
	^ id! !

!ORWorkspaceUser methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:33'!
id: aString
	id := aString
! !

!ORWorkspaceUser methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:33'!
userName
	^ userName! !

!ORWorkspaceUser methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:33'!
userName: aString
	userName := aString
! !

!ORWorkspaceUser methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:33'!
workspaces
	^ workspaces! !

!ORWorkspaceUser methodsFor: 'accessing' stamp: 'pmm 3/28/2011 04:33'!
workspaces: aCollectionOfOrWorkspace
	workspaces := aCollectionOfOrWorkspace! !

Object subclass: #ORFileImplementation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Implementation'!

Object subclass: #OROrionImplementation
	instanceVariableNames: 'fileImplementation workspaceImplementation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Implementation'!

!OROrionImplementation methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:25'!
fileImplementation
	^ fileImplementation! !

!OROrionImplementation methodsFor: 'accessing' stamp: 'pmm 3/23/2011 07:26'!
workspaceImplementation
	^ workspaceImplementation! !

Object subclass: #ORWorkspaceImplementation
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orion-Implementation'!

!ORWorkspaceImplementation methodsFor: 'public' stamp: 'pmm 3/23/2011 07:28'!
addNewProjectToWorkspace: workspaceId
	self subclassResponsibility! !

!ORWorkspaceImplementation methodsFor: 'public' stamp: 'pmm 3/23/2011 07:29'!
createNewWorkspace: slug
	self subclassResponsibility! !
